@@ -22,11 +22,9 @@ class BaseFrameContainer extends Core
 	private $joomlaBufArray = array();			// Joomla!データ受け渡し用
 	private $templateCustomObj;				// テンプレートカスタマイズパラメータオブジェクト
 	const SYSTEM_TEMPLATE = '_system';		// システム画面用テンプレート
-	const M_ADMIN_TEMPLATE = 'm/_admin';	// 携帯用管理画面テンプレート
 	const ERR_MESSAGE_ACCESS_DENY = 'Access denied.';		// ウィジェットアクセスエラーのメッセージ
 	const SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
 	const CONFIG_KEY_MSG_TEMPLATE = 'msg_template';			// メッセージ用テンプレート取得キー
-//	const CF_MOBILE_AUTO_REDIRECT = 'mobile_auto_redirect';		// 携帯の自動遷移
 	const TEMPLATE_GENERATOR_THEMLER = 'themler';			// テンプレート作成アプリケーション(Themler)
 		
 	/**
@@ -276,14 +274,6 @@ class BaseFrameContainer extends Core
 				return;
 			}
 			// #################### URLの遷移 #######################
-			//if ($this->gSystem->getSystemConfig(self::CF_MOBILE_AUTO_REDIRECT)){		// 携帯自動遷移を行う場合
-			if ($this->gSystem->mobileAutoRedirect()){		// 携帯自動遷移を行う場合
-				// 携帯のときは携帯用URLへ遷移
-				if ($this->gEnv->isMobile() && !$this->gEnv->getIsMobileSite()){
-					$this->gPage->redirect($this->gEnv->getDefaultMobileUrl(true/*携帯用パラメータ付加*/), true/*遷移時のダイアログ表示を抑止*/);
-					return;
-				}
-			}
 			if ($this->gSystem->smartphoneAutoRedirect()){		// スマートフォン自動遷移を行う場合
 				// スマートフォンのときはスマートフォンURLへ遷移
 				if ($this->gEnv->isSmartphone() && !$this->gEnv->getIsSmartphoneSite()){
@@ -454,7 +444,7 @@ class BaseFrameContainer extends Core
 			}
 			
 			// 管理権限がない場合は、ウィジェットのページへの配置状況からアクセス権限をチェックする
-			if (!$isSystemManageUser && !$this->gAccess->isValidAdminKey() && !$this->_db->canAccessWidget($widgetId)){
+			if (!$isSystemManageUser && !$this->_db->canAccessWidget($widgetId)){
 				// アクセスエラーのログを残す
 				$this->_db->writeWidgetLog($widgetId, 1/*単体実行*/, $cmd, self::ERR_MESSAGE_ACCESS_DENY);
 				
@@ -464,7 +454,7 @@ class BaseFrameContainer extends Core
 			}
 			
 			// ################# パラメータチェック ################
-			if (!$isSystemManageUser && !$this->gAccess->isValidAdminKey() && $this->gEnv->isServerConnector()){		// サーバ接続の場合
+			if (!$isSystemManageUser && $this->gEnv->isServerConnector()){		// サーバ接続の場合
 				// クエリーパラメータはウィジェットIDのみ正常とする
 				$params = $request->getQueryArray();
 				$paramCount = count($params);
@@ -672,27 +662,15 @@ class BaseFrameContainer extends Core
 		// カレントのテンプレートIDを設定
 		$this->gEnv->setCurrentTemplateId($curTemplate, $subTemplateId);
 
-		// テンプレート情報を取得
-		$convType = 0;		// 変換処理タイプ(0=デフォルト(Joomla!v1.0)、-1=携帯用、1=Joomla!v1.5、2=Joomla!v2.5)
-		if ($this->gEnv->getIsMobileSite()){
-			$convType = -1;		// 携帯サイト用変換
-		} else {
-			// テンプレートタイプを取得(0=デフォルト(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5)
-			$convType = $this->gEnv->getCurrentTemplateType();
-		}
+		// テンプレートタイプを取得(0=デフォルト(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5)
+		$convType = $this->gEnv->getCurrentTemplateType();
 
 		// バッファリングの準備
 		if (method_exists($this, '_prepareBuffer')) $this->_prepareBuffer($request);
 	
 		// ################### バッファリング開始 ######################
 		// ob_end_flush()までの出力をバッファリングする
-		if ($convType == -1){// 携帯用サイトの場合は出力エンコーディングを変更
-			$mobileEncoding = $this->gEnv->getMobileEncoding();		// 携帯用エンコーディングを取得
-			mb_http_output($mobileEncoding);
-			ob_start("mb_output_handler"); // 出力のバッファリング開始
-		} else {
-			ob_start();
-		}
+		ob_start();
 
 		// サブクラスの前処理を実行
 		if (method_exists($this, '_preBuffer')) $this->_preBuffer($request);
@@ -941,8 +919,6 @@ class BaseFrameContainer extends Core
 				break;
 			case M3_VIEW_TYPE_WIKI:	// Wiki
 				break;
-			case M3_VIEW_TYPE_USER:	// ユーザ作成コンテンツ
-				break;
 			case M3_VIEW_TYPE_EVENT:	// イベント
 				break;
 			case M3_VIEW_TYPE_PHOTO:	// フォトギャラリー
@@ -1133,17 +1109,6 @@ class BaseFrameContainer extends Core
 	
 		// 遅延実行ウィジェットの出力を埋め込む。HTMLヘッダ出力する。
 		$destContents = $this->gPage->lateLaunchWidget($request, $srcContents);
-
-		// 携帯インターフェイスのときのときは、手動変換後、バイナリコード(絵文字等)を埋め込む
-		if ($convType == -1){			// 携帯アクセスポイントの場合
-			// 出力するコードに変換
-			$destContents = mb_convert_encoding($destContents, $mobileEncoding, M3_ENCODING);
-	
-			// コンテンツ変換メソッドがある場合は実行
-			if (method_exists($this, '_convContents')){
-				$destContents = $this->_convContents($destContents);// 絵文字埋め込み処理等
-			}
-		}
 		
 		// ##### CSS生成の場合は、すべてのウィジェット実行後出力を削除する #####
 		if ($cmd == M3_REQUEST_CMD_CSS) $destContents = '';		// CSS生成のとき
@@ -1181,15 +1146,7 @@ class BaseFrameContainer extends Core
 		$subTemplateId = '';
 		$isSystemManageUser = $this->gEnv->isSystemManageUser();		// システム運用可能かどうか
 		$useSubClassDefine = true;			// サブクラスでの定義を使用するかどうか
-		
-		// テンプレート変更のときは、セッションのテンプレートIDを変更
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);		// 実行コマンドを取得
-		if ($cmd == M3_REQUEST_CMD_CHANGE_TEMPLATE){
-			// テンプレートIDをセッションに残す場合
-			if ($this->gSystem->useTemplateIdInSession()){		// セッションに保存する場合
-				$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $request->trimValueOf(M3_SYSTEM_TAG_CHANGE_TEMPLATE));
-			}
-		}
 
 		// サブクラスでテンプレートIDを指定している場合はそちらを使用
 		$templateDefined = false;		// テンプレート固定かどうか
@@ -1229,8 +1186,6 @@ class BaseFrameContainer extends Core
 					if ($pageId == $this->gEnv->getDefaultPageId()){		// 通常サイトのとき
 						$curTemplate = $this->gSystem->defaultTemplateId();
 						$subTemplateId = $this->gSystem->defaultSubTemplateId();
-					} else if ($pageId == $this->gEnv->getDefaultMobilePageId()){		// 携帯サイトのとき
-						$curTemplate = $this->gSystem->defaultMobileTemplateId();		// 携帯用デフォルトテンプレート
 					} else if ($pageId == $this->gEnv->getDefaultSmartphonePageId()){		// スマートフォン用サイトのとき
 						$curTemplate = $this->gSystem->defaultSmartphoneTemplateId();		// スマートフォン用デフォルトテンプレート
 					} else if ($pageId == $this->gEnv->getDefaultAdminPageId() ||		// 管理サイトのとき
@@ -1246,15 +1201,6 @@ class BaseFrameContainer extends Core
 				// ページ用のテンプレートがあるときは優先
 				$pageTemplateId = $this->gPage->getTemplateIdFromCurrentPageInfo($subTemplateId);
 				if (!empty($pageTemplateId)) $curTemplate = $pageTemplateId;
-
-				// テンプレートIDをセッションから取得
-				if (empty($curTemplate) && !$isSystemManageUser){			// システム運用者はセッション値を使用できない
-					if ($this->gSystem->useTemplateIdInSession()){		// セッションに保存する場合
-						if (!$this->gEnv->getIsMobileSite() && !$this->gEnv->getIsSmartphoneSite()){
-							$curTemplate = $request->getSessionValue(M3_SESSION_CURRENT_TEMPLATE);// 携帯サイト、スマートフォンサイトでないときはセッション値を取得
-						}
-					}
-				}
 				
 				// オプションのテンプレートがある場合はオプションを優先
 				list($optionTemplate, $optionSubTemplate) = $this->gPage->getOptionTemplateId();
@@ -1266,9 +1212,7 @@ class BaseFrameContainer extends Core
 				
 				// セッションにないときはデフォルトを取得
 				if (empty($curTemplate)){
-					if ($this->gEnv->getIsMobileSite()){// 携帯用サイトの場合
-						$curTemplate = $this->gSystem->defaultMobileTemplateId();		// 携帯用デフォルトテンプレート
-					} else if ($this->gEnv->getIsSmartphoneSite()){// スマートフォン用サイトの場合
+					if ($this->gEnv->getIsSmartphoneSite()){// スマートフォン用サイトの場合
 						$curTemplate = $this->gSystem->defaultSmartphoneTemplateId();		// スマートフォン用デフォルトテンプレート
 					} else {
 						$curTemplate = $this->gSystem->defaultTemplateId();
@@ -1282,17 +1226,6 @@ class BaseFrameContainer extends Core
 			// テンプレートが１つもみつからないときは、管理用テンプレートを使用
 			$curTemplate = $this->gSystem->defaultAdminTemplateId();
 			echo 'template not found. viewing by administration template. [' . $curTemplate . ']';
-		} else {	// セッションにテンプレートIDを保存
-			// テンプレートIDをセッションに残す場合
-/*			if ($this->gSystem->useTemplateIdInSession()){		// セッションに保存する場合
-				if ($cmd == M3_REQUEST_CMD_SHOW_POSITION ||				// 表示位置を表示するとき
-					$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){	// 表示位置を表示するとき(ウィジェット付き)
-				} else {
-					if (!$this->gEnv->getIsMobileSite() && !$this->gEnv->getIsSmartphoneSite() && !$templateDefined){		// PC用画面でサブクラス固定でないとき場合は保存
-						$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $curTemplate);
-					}
-				}
-			}*/
 		}
 		return $curTemplate;
 	}
@@ -1310,8 +1243,6 @@ class BaseFrameContainer extends Core
 			// PC用サイト、携帯用サイト、スマートフォン用サイトの公開状況をチェック
 			if ($this->gEnv->getIsPcSite()){
 				if ($this->gSystem->sitePcInPublic()) return true;
-			} else if ($this->gEnv->getIsMobileSite()){
-				if ($this->gSystem->siteMobileInPublic()) return true;
 			} else if ($this->gEnv->getIsSmartphoneSite()){
 				if ($this->gSystem->siteSmartphoneInPublic()) return true;
 			}
@@ -1342,20 +1273,16 @@ class BaseFrameContainer extends Core
 		
 		// テンプレートの設定
 		// DBで設定されている値を取得し、なければ管理用デフォルトテンプレートを使用
-		if ($this->gEnv->getIsMobileSite()){		// 携帯用サイトのアクセスの場合
-			$curTemplateId = self::M_ADMIN_TEMPLATE;	// 携帯管理画面用テンプレート
-		} else {			// 携帯以外のサイトへのアクセスの場合
-			if ($type == 1){			// ログインはデフォルトの管理画面テンプレートに固定
-				$curTemplateId = $this->gSystem->defaultAdminTemplateId();
+		if ($type == 1){			// ログインはデフォルトの管理画面テンプレートに固定
+			$curTemplateId = $this->gSystem->defaultAdminTemplateId();
+		} else {
+			$curTemplateId = $this->gSystem->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
+			if (empty($curTemplateId)){
+				$curTemplateId = self::SYSTEM_TEMPLATE;// システム画面用テンプレート
 			} else {
-				$curTemplateId = $this->gSystem->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
-				if (empty($curTemplateId)){
-					$curTemplateId = self::SYSTEM_TEMPLATE;// システム画面用テンプレート
-				} else {
-					// テンプレートの存在チェック
-					$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplateId . '/' . M3_FILENAME_INDEX;
-					if (!file_exists($templateIndexFile)) $curTemplateId = self::SYSTEM_TEMPLATE;// システム画面用テンプレート
-				}
+				// テンプレートの存在チェック
+				$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplateId . '/' . M3_FILENAME_INDEX;
+				if (!file_exists($templateIndexFile)) $curTemplateId = self::SYSTEM_TEMPLATE;// システム画面用テンプレート
 			}
 		}
 
