@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 2.31.x SVN: $Id$
+ * @version    Release 3.0.x SVN: $Id$
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -58,8 +58,8 @@ define('M3_TITLE_BRACKET_END',		'」');					// タイトルを括弧表記する
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.31.5');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2018/9/12');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'3.0.0');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2018/11/1');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -99,7 +99,6 @@ define('M3_TAG_MACRO_IMG_URL',		'M3_IMG_URL');							// 画像URLを示すマク
 define('M3_TAG_MACRO_LINK_URL',		'M3_LINK_URL');							// リンク先URLを示すマクロ
 define('M3_TAG_MACRO_WIDGET_URL',	'M3_WIDGET_URL');						// 個別のウィジェットのルートURLを示すマクロ
 define('M3_TAG_MACRO_WIDGET_CSS_ID',	'M3_WIDGET_CSS_ID');				// 個別のウィジェットのCSS用IDを示すマクロ
-define('M3_TAG_MACRO_EMOJI_CODE',	'M3_EMOJI');							// 絵文字コード
 define('M3_TAG_MACRO_SEPARATOR',	'M3_$');								// テキストデータセパレータ
 define('M3_TAG_MACRO_SITE_KEY',		'SITE_');								// サイト定義置換キー
 define('M3_TAG_MACRO_CUSTOM_KEY',	'CUSTOM_KEY_');							// 汎用置換キー
@@ -212,7 +211,6 @@ define('M3_TEMPLATE_JOOMLA_10',			0);		// Joomla!v1.0テンプレート
 define('M3_TEMPLATE_JOOMLA_15',			1);		// Joomla!v1.5テンプレート
 define('M3_TEMPLATE_JOOMLA_25',			2);		// Joomla!v2.5テンプレート
 define('M3_TEMPLATE_BOOTSTRAP_30',		10);		// Bootstrap v3.0テンプレート
-define('M3_TEMPLATE_JQUERY_MOBILE_10',	20);		// jQuery Mobile v1.0テンプレート
 // テンプレート作成アプリケーションタイプ
 define('M3_TEMPLATE_GENERATOR_ARTISTEER',	'artisteer');	// Artisteer
 define('M3_TEMPLATE_GENERATOR_THEMLER',		'themler');		// Themler
@@ -222,7 +220,6 @@ define('M3_RENDER_JOOMLA_OLD',		'joomla_old');		// Joomla! 1.0テンプレート
 define('M3_RENDER_JOOMLA_NEW',		'joomla_new');		// Joomla! 1.5以上のテンプレート
 define('M3_RENDER_BOOTSTRAP',		'bootstrap');		// Bootstrap 3.0テンプレート
 define('M3_RENDER_WORDPRESS',		'wordpress');		// WordPressテンプレート
-define('M3_RENDER_JQUERY_MOBILE',	'jquery mobile');	// jQuery Mobileテンプレート
 	
 // ファイル拡張子
 define('M3_TEMPLATE_FILE_EXTENSION', '.tmpl.html');		// テンプレートファイルの拡張子(suffix)
@@ -254,15 +251,14 @@ define('M3_VIEW_TYPE_SEARCH',		'search');				// 検索結果
 define('M3_VIEW_TYPE_COMMERCE',		'commerce');			// Eコマース
 define('M3_VIEW_TYPE_CALENDAR',		'calendar');			// カレンダー
 // コンテンツタイプ
-define('M3_VIEW_TYPE_MEMBER',		'member');				// 会員情報
 define('M3_VIEW_TYPE_CONTENT',		'content');				// 汎用コンテンツ
+define('M3_VIEW_TYPE_BLOG',			'blog');				// ブログ
 define('M3_VIEW_TYPE_PRODUCT',		'product');				// 商品情報
 define('M3_VIEW_TYPE_BBS',			'bbs');					// BBS
-define('M3_VIEW_TYPE_BLOG',			'blog');				// ブログ
 define('M3_VIEW_TYPE_WIKI',			'wiki');				// Wiki
-define('M3_VIEW_TYPE_USER',			'user');				// ユーザ作成コンテンツ
 define('M3_VIEW_TYPE_EVENT',		'event');				// イベント情報
 define('M3_VIEW_TYPE_PHOTO',		'photo');				// フォトギャラリー
+define('M3_VIEW_TYPE_MEMBER',		'member');				// 会員情報
 // 補助コンテンツ
 define('M3_VIEW_TYPE_NEWS',			'news');				// 新着情報
 define('M3_VIEW_TYPE_COMMENT',		'comment');				// コメント
@@ -284,7 +280,6 @@ $M3_ALL_CONTENT_TYPE	= array(	M3_VIEW_TYPE_NEWS,				// 新着情報
 									M3_VIEW_TYPE_BBS,				// BBS
 									M3_VIEW_TYPE_BLOG,				// ブログ
 									M3_VIEW_TYPE_WIKI,				// Wiki
-									M3_VIEW_TYPE_USER,				// ユーザ作成コンテンツ
 									M3_VIEW_TYPE_EVENT,				// イベント情報
 									M3_VIEW_TYPE_EVENTENTRY,		// イベント予約
 									M3_VIEW_TYPE_PHOTO);			// フォトギャラリー
@@ -296,7 +291,6 @@ define('M3_CONTENT_KEY_PAGE_NOT_FOUND',	'PAGE_NOT_FOUND');				// ページが見
 
 // ウィジェットタイプ
 define('M3_WIDGET_TYPE_MENU',	'menu');				// メニュー
-define('M3_WIDGET_TYPE_USER',	'user');				// ユーザ作成コンテンツ
 
 // 作業用
 define('M3_SYSTEM_WORK_DIR_PATH', 				'/tmp');			// 作業用ディレクトリ
@@ -356,7 +350,6 @@ define('M3_REQUEST_PARAM_OPERATION_TODO',      		'todo');			// 指定ウィジ
 define('M3_REQUEST_PARAM_FROM',						'from');			// メッセージの送信元ウィジェットID。遷移元画面。
 define('M3_REQUEST_PARAM_VIEW_STYLE',				'style');			// 表示スタイル
 define('M3_REQUEST_PARAM_FORWARD',					'forward');			// 画面遷移用パラメータ
-define('M3_REQUEST_PARAM_ADMIN_KEY',				'adminkey');		// 管理者一時キー
 define('M3_REQUEST_PARAM_OPEN_BY',					'openby');			// ウィンドウの開き方
 define('M3_REQUEST_PARAM_SHOW_HEADER',				'head');			// ヘッダ部表示制御
 define('M3_REQUEST_PARAM_SHOW_FOOTER',				'foot');			// フッタ部表示制御
@@ -372,6 +365,7 @@ define('M3_REQUEST_PARAM_TOKEN',					'_token');			// POSTデータトークン
 define('M3_REQUEST_PARAM_BACK_URL',					'_backurl');		// 戻り先URL
 define('M3_REQUEST_PARAM_BACKUP_URL',				'_backupurl');		// URL退避用(画面編集時)
 define('M3_REQUEST_PARAM_SERVER',					'_server');			// サーバ指定
+define('M3_REQUEST_PARAM_USER_ID',      			'userid');			// ユーザID
 define('M3_REQUEST_PARAM_FILE_ID',      			'fileid');			// ファイルID
 define('M3_REQUEST_PARAM_CATEGORY_ID',      		'categoryid');		// カテゴリID
 define('M3_REQUEST_PARAM_YEAR',      				'year');			// 年
@@ -393,10 +387,6 @@ define('M3_REQUEST_PARAM_BBS_ID',      				'bbsid');			// 掲示板投稿記事I
 define('M3_REQUEST_PARAM_BBS_ID_SHORT',      		'sid');				// 掲示板投稿記事ID(略式)
 define('M3_REQUEST_PARAM_BBS_THREAD_ID',      		'threadid');		// 掲示板投稿スレッドID
 define('M3_REQUEST_PARAM_BBS_THREAD_ID_SHORT',      'tid');				// 掲示板投稿スレッドID(略式)
-define('M3_REQUEST_PARAM_USER_ID',      			'userid');			// ユーザ作成コンテンツID
-define('M3_REQUEST_PARAM_USER_ID_SHORT',      		'uid');				// ユーザ作成コンテンツID(略式)
-define('M3_REQUEST_PARAM_ROOM_ID',      			'roomid');			// ユーザ作成コンテンツ区画ID
-define('M3_REQUEST_PARAM_ROOM_ID_SHORT',      		'rid');				// ユーザ作成コンテンツ区画ID(略式)
 define('M3_REQUEST_PARAM_EVENT_ID',      			'eventid');			// イベントID
 define('M3_REQUEST_PARAM_EVENT_ID_SHORT',      		'vid');				// イベントID(略式)
 define('M3_REQUEST_PARAM_PHOTO_ID',      			'photoid');			// 画像ID
