@@ -52,7 +52,6 @@ class CacheManager extends Core
 			//M3_REQUEST_PARAM_FROM,			// メッセージの送信元ウィジェットID
 			//M3_REQUEST_PARAM_VIEW_STYLE,			// 表示スタイル
 			//M3_REQUEST_PARAM_FORWARD,			// 画面遷移用パラメータ
-			//M3_REQUEST_PARAM_ADMIN_KEY,		// 管理者一時キー
 			//M3_REQUEST_PARAM_OPEN_BY,			// ウィンドウの開き方
 			//M3_REQUEST_PARAM_SHOW_HEADER,			// ヘッダ部表示制御
 			//M3_REQUEST_PARAM_SHOW_FOOTER,			// フッタ部表示制御
@@ -329,9 +328,6 @@ class CacheManager extends Core
 		// 管理画面はキャッシュ機能は使用できない
 		if ($gEnvManager->isAdminDirAccess()) return false;
 		
-		// 携帯はSJIS出力なので非対応
-		if ($gEnvManager->getIsMobileSite()) return false;
-		
 		// GET以外はキャッシュしない
 		$method = strtoupper($request->trimServerValueOf('REQUEST_METHOD'));	// アクセスメソッド
 		if ($method != 'GET') return false;
