@@ -77,23 +77,13 @@ function m3AdjustHeight(obj, min)
 // 一般ウィンドウ表示
 function m3ShowStandardWindow(url)
 {
-	if (M3_CONFIG_WINDOW_OPEN_TYPE == 0){
-		window.open(url, "", "toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=1050,height=900");
-	} else {
-		window.open(url, "");
-	}
+	window.open(url, "");
 }
 // 設定用ウィンドウ表示
 function m3ShowConfigWindow(widgetId, configId, serial)
 {
-	if (M3_CONFIG_WINDOW_OPEN_TYPE == 0){
-		window.open(M3_DEFAULT_ADMIN_URL + "?cmd=configwidget&openby=other&widget=" + widgetId + 
-					"&_defconfig=" + configId + "&_defserial=" + serial, "config_" + widgetId,
-					"toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=1050,height=900");
-	} else {
-		window.open(M3_DEFAULT_ADMIN_URL + "?cmd=configwidget&openby=other&widget=" + widgetId + 
+	window.open(M3_DEFAULT_ADMIN_URL + "?cmd=configwidget&openby=other&widget=" + widgetId + 
 					"&_defconfig=" + configId + "&_defserial=" + serial, "config_" + widgetId);
-	}
 }
 // テンプレート設定用ウィンドウ表示
 function m3ShowTemplateConfigWindow(templateId)
@@ -103,14 +93,8 @@ function m3ShowTemplateConfigWindow(templateId)
 // ウィジェット表示微調整用ウィンドウ表示
 function m3ShowAdjustWindow(configId, serial, pageId, pageSubId)
 {
-	if (M3_CONFIG_WINDOW_OPEN_TYPE == 0){
-		window.open(M3_DEFAULT_ADMIN_URL + "?task=adjustwidget&openby=simple" + 
-					"&_defconfig=" + configId + "&_defserial=" + serial + "&_page=" + pageId + "&_sub=" + pageSubId, "adjust_" + serial,
-					"toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=1050,height=900");
-	} else {
-		window.open(M3_DEFAULT_ADMIN_URL + "?task=adjustwidget&openby=simple" + 
+	window.open(M3_DEFAULT_ADMIN_URL + "?task=adjustwidget&openby=simple" + 
 					"&_defconfig=" + configId + "&_defserial=" + serial + "&_page=" + pageId + "&_sub=" + pageSubId, "adjust_" + serial);
-	}
 }
 // 各種端末用プレビューウィンドウ表示
 function m3ShowPreviewWindow(type, url)
@@ -459,28 +443,6 @@ function m3OpenFlashFileBrowser(seturl_callback)
 		}
 	});
 }
-/**
- * TextAreaをHTMLエディターに変更
- *
- * @param string id			TextAreaタグのIDまたはname
- * @param bool	isMobile	携帯用のツールバー表示
- * @return なし
- */
-function m3_setHtmlEditor(id, isMobile)
-{
-	var oFCKeditor		= new FCKeditor(id);
-	oFCKeditor.BasePath	= M3_ROOT_URL + '/scripts/fckeditor2.6.6/';
-	oFCKeditor.Config['CustomConfigurationsPath'] = M3_ROOT_URL + '/scripts/m3/fckconfig.js';
-	if (isMobile == null || isMobile == false){
-		oFCKeditor.ToolbarSet	= "M3Default";			// ツールバーリソース名
-	} else {
-		oFCKeditor.ToolbarSet	= "M3MobileDefault";	// ツールバーリソース名
-	}
-	oFCKeditor.Width	= "100%";
-	oFCKeditor.Height	= "100%";
-	oFCKeditor.Value	= 'This is some <strong>sample text<\/strong>. You are using <a href="http://www.fckeditor.net/">FCKeditor<\/a>.';
-	oFCKeditor.ReplaceTextarea();
-}
 /**
  * TextAreaをWYSIWYGエディターに変更
  *
@@ -499,43 +461,34 @@ function m3SetWysiwygEditor(id, height, toolbarVisible, barType, width)
 	// アクセスポイントの設定
 	_m3SetAccessPoint(M3_CONFIG_WIDGET_DEVICE_TYPE);
 		
-	if (M3_WYSIWYG_EDITOR == 'ckeditor'){
-		var config = {};
-		
-		config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig.js';
-		if (height) config['height'] = height;
-		if (width) config['width'] = width;
-		if (toolbarVisible != null && !toolbarVisible) config['toolbarStartupExpanded'] = false;
-		
-		if (barType){
-			switch (barType){
-			case 'full':
-			default:
-				config['toolbar'] = 'Full';
-				if (typeof(M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES) != "undefined") config['contentsCss'] = M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES;
-				break;
-			case 'layout':
-				config['toolbar'] = 'Layout';
-				if (typeof(M3_CONFIG_WIDGET_CKEDITOR_LAYOUT_CSS_FILES) != "undefined") config['contentsCss'] = M3_CONFIG_WIDGET_CKEDITOR_LAYOUT_CSS_FILES;
-				break;
-			case 'small':
-				config['toolbar'] = 'Small';
-				break;
-			}
-		} else {
+
+	var config = {};
+	
+	config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig.js';
+	if (height) config['height'] = height;
+	if (width) config['width'] = width;
+	if (toolbarVisible != null && !toolbarVisible) config['toolbarStartupExpanded'] = false;
+	
+	if (barType){
+		switch (barType){
+		case 'full':
+		default:
 			config['toolbar'] = 'Full';
 			if (typeof(M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES) != "undefined") config['contentsCss'] = M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES;
+			break;
+		case 'layout':
+			config['toolbar'] = 'Layout';
+			if (typeof(M3_CONFIG_WIDGET_CKEDITOR_LAYOUT_CSS_FILES) != "undefined") config['contentsCss'] = M3_CONFIG_WIDGET_CKEDITOR_LAYOUT_CSS_FILES;
+			break;
+		case 'small':
+			config['toolbar'] = 'Small';
+			break;
 		}
-		CKEDITOR.replace(id, config);
 	} else {
-		var oFCKeditor		= new FCKeditor(id);
-		oFCKeditor.BasePath	= M3_ROOT_URL + '/scripts/fckeditor2.6.6/';
-		oFCKeditor.Config['CustomConfigurationsPath'] = M3_ROOT_URL + '/scripts/m3/fckconfig.js';
-		oFCKeditor.ToolbarSet	= "M3Default";			// ツールバーリソース名
-		if (height) oFCKeditor.Height = String(height) + 'px';
-		oFCKeditor.Value	= 'This is some <strong>sample text<\/strong>. You are using <a href="http://www.fckeditor.net/">FCKeditor<\/a>.';
-		oFCKeditor.ReplaceTextarea();
+		config['toolbar'] = 'Full';
+		if (typeof(M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES) != "undefined") config['contentsCss'] = M3_CONFIG_WIDGET_CKEDITOR_CSS_FILES;
 	}
+	CKEDITOR.replace(id, config);
 }
 /**
  * TextAreaをスクリプト編集エディターに変更
