@@ -5,19 +5,14 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 <patTemplate:tmpl name="_tmpl">
-$(function(){
-	// アンカーの移動位置を修正
-	var paddingTop = $('body').css('padding-top');
-	if (paddingTop) $('.anchor_super').css('padding-top', paddingTop).css('margin-top', '-' + paddingTop);
-//	if (paddingTop) $('.anchor_super').css('padding-top', paddingTop);
-//	if (paddingTop) $('.anchor_super').css('margin-top', paddingTop);
 <patTemplate:tmpl name="fileselect" visibility="hidden">
+$(function(){
 	// アップロードファイル選択
 	$('.btn-file :file').on('fileselect', function(event, numFiles, label){
 		var input = $(this).parents('.input-group').find(':text'),
@@ -36,6 +31,6 @@ $(function(){
 	        label = input.val().replace(/\\/g, '/').replace(/.*\//, '');
 	    input.trigger('fileselect', [numFiles, label]);
 	});
-</patTemplate:tmpl>
 });
 </patTemplate:tmpl>
+</patTemplate:tmpl>
